Exception: SyntaxTree::XML::Parser::MissingTokenError
- Inherits:
-
ParseError
- Object
- StandardError
- ParseError
- SyntaxTree::XML::Parser::MissingTokenError
- Defined in:
- lib/syntax_tree/xml/parser.rb
Overview
This error occurs when a certain token is expected in a certain place but is not found. Sometimes this is handled internally because some elements are optional. Other times it is not and it is raised to end the parsing process.